@@ -7,7 +7,7 @@ use parent 'Net::SecurityCenter::API';
 
 use Net::SecurityCenter::Utils qw(:all);
 
-our $VERSION = '0.205';
+our $VERSION = '0.206';
 
 #-------------------------------------------------------------------------------
 # METHODS
@@ -17,22 +17,8 @@ sub get_status {
 
     my ( $self, %args ) = @_;
 
-    my $tmpl = {
-        fields => {
-            filter => \&sc_filter_array_to_string
-        },
-        raw => {},
-    };
-
-    my $params = sc_check_params( $tmpl, \%args );
-    my $raw    = delete( $params->{'raw'} );
-    my $status = $self->client->get( '/status', $params );
-
-    if ($raw) {
-        return $status;
-    }
-
-    return sc_normalize_hash($status);
+    deprecated
+        '"Net::SecurityCenter::API::System->get_status" is DEPRECATED use "Net::SecurityCenter::API::Status->status" instead';
 
 }
 
@@ -42,6 +28,19 @@ sub get_info {
 
     my ( $self, %args ) = @_;
 
+    deprecated
+        '"Net::SecurityCenter::API::Status->get_info" is DEPRECATED use "Net::SecurityCenter::API::Status->info"';
+
+    return $self->info( \%args );
+
+}
+
+#-------------------------------------------------------------------------------
+
+sub info {
+
+    my ( $self, %args ) = @_;
+
     my $tmpl = { raw => {}, };
 
     my $params = sc_check_params( $tmpl, \%args );
@@ -62,6 +61,57 @@ sub get_info {
 
 #-------------------------------------------------------------------------------
 
+sub debug {
+
+    my ( $self, %args ) = @_;
+
+    my $tmpl = { name => {}, id => {}, category => {} };
+
+    my $params   = sc_check_params( $tmpl, \%args );
+    my $id       = delete( $params->{'id'} );
+    my $name     = delete( $params->{'name'} );
+    my $category = delete( $params->{'category'} );
+    my $debug    = $self->client->get('/system/debug');
+
+    if ( !$debug ) {
+        return;
+    }
+
+    my $id_results       = {};
+    my $name_results     = {};
+    my $category_results = {};
+
+    foreach my $item ( @{$debug} ) {
+
+        $id_results->{ $item->{id} }     = $item;
+        $name_results->{ $item->{name} } = $item;
+
+        if ( !defined( $category_results->{ $item->{category} } ) ) {
+            $category_results->{ $item->{category} } = ();
+        }
+
+        push @{ $category_results->{ $item->{category} } }, $item;
+
+    }
+
+    if ($name) {
+        return $name_results->{$name};
+    }
+
+    if ($id) {
+        return $id_results->{$id};
+    }
+
+    if ($category) {
+        return $category_results->{$category};
+    }
+
+    return $debug;
+
+}
+
+#-------------------------------------------------------------------------------
+
 sub get_diagnostics_info {
 
     my ( $self, %args ) = @_;
@@ -178,12 +228,38 @@ Create a new instance of B<Net::SecurityCenter::API::System> using L<Net::Securi
 
 =head2 get_status
 
-Gets a collection of status information, including license.
+DEPRECATED use L<Net::SecurityCenter::API::Status>->status method.
 
-=head2 get_info
+=head2 info
+=head2 get_info (DEPRECATED)
 
 Gets the system initialization information.
 
+=head2 debug
+
+    # Get all Tenble.sc debug informations
+    my @debug = $sc->debug;
+
+    # Check scan debug flag
+    if ($sc->debug( id => 60 )->{enabled} eq 'true' ) {
+        say "Scan Debug enabled!";
+    }
+
+    # Get all "common" debug category
+    my @common = $sc->debug( category => 'common' );
+
+Params:
+
+=over 4
+
+=item * C<id> : ID of debug item
+
+=item * C<name> : Name of category
+
+=item * C<category> : Debug category
+
+=back
+
 =head2 get_diagnostics_info
 
 Gets the system diagnostics information.
@@ -230,7 +306,7 @@ L<https://github.com/giterlizzi/perl-Net-SecurityCenter>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is copyright (c) 2018-2019 by Giuseppe Di Terlizzi.
+This software is copyright (c) 2018-2020 by Giuseppe Di Terlizzi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
